@@ -31,17 +31,19 @@ class ContactEditorMainWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit ContactEditorMainWindow();
-    ~ContactEditorMainWindow();
+    ~ContactEditorMainWindow() override;
 
 protected:
     void closeEvent(QCloseEvent *) override;
 
+private Q_SLOTS:
+    void slotUploadTheme();
+
 private:
     void slotNewTheme();
     void slotCloseTheme();
     void slotAddExtraPage();
     void slotOpenTheme();
-    void slotUploadTheme();
     void slotQuitApp();
     bool slotSaveTheme();
     void slotInstallTheme();
